@@ -6,6 +6,7 @@ from . import build_clueweb_warc_indexes
 from . import build_download_cache
 from . import build_c4_checkpoints
 from . import clean
+from . import generate_metadata
 
 COMMANDS = {
 	'doc_fifos': doc_fifos.main,
@@ -16,4 +17,5 @@ COMMANDS = {
     'build_c4_checkpoints': build_c4_checkpoints.main,
     'build_download_cache': build_download_cache.main,
     'clean': clean.main,
+    'generate_metadata': generate_metadata.main,
 }
