@@ -11,7 +11,7 @@ _logger = ir_datasets.log.easy()
 
 class Dataset:
     def __init__(self, *constituents):
-        self._constituents = constituents
+        self._constituents = [c for c in constituents if c is not None]
         self._beta_apis = {}
 
     def __getstate__(self):
@@ -306,6 +306,9 @@ class FilteredQueries(BaseQueries):
     def queries_handler(self):
         return self
 
+    def queries_lang(self):
+        return self._queries_handler.queries_lang()
+
 
 class FilteredQrels(BaseQrels):
     def __init__(self, qrels_handler, lazy_qids, mode='include'):
@@ -398,6 +401,14 @@ class YamlDocumentationProvider:
         return {}
 
 
+class Deprecated:
+    def __init__(self, message):
+        self._message = message
+
+    def deprecated(self):
+        return self._message
+
+
 class ExpectedFile:
     def __init__(self, path, expected_md5=None, instructions=None):
         self._path = Path(path)
