@@ -8,7 +8,7 @@ from glob import glob
 from pathlib import Path
 import ir_datasets
 from ir_datasets.util import DownloadConfig, TarExtract, TarExtractAll, Cache, Bz2Extract, ZipExtract, IterStream
-from ir_datasets.formats import TrecQrels, TrecDocs, TrecXmlQueries, WarcDocs, GenericDoc, GenericQuery, TrecQrel, NtcirQrels, TrecSubtopic
+from ir_datasets.formats import TrecQrels, TrecSubQrels, TrecDocs, TrecXmlQueries, WarcDocs, GenericDoc, GenericQuery, TrecQrel, TrecSubQrel, NtcirQrels, TrecSubtopic
 from ir_datasets.datasets.base import Dataset, FilteredQueries, FilteredQrels, YamlDocumentation
 from ir_datasets.indices import Docstore, CacheDocstore
 
@@ -273,6 +273,12 @@ def _init():
         TrecXmlQueries(dlc['trec-web-2013/queries'], qtype=TrecWebTrackQuery, namespace='trec-web', lang='en'),
         TrecQrels(dlc['trec-web-2013/qrels.adhoc'], QREL_DEFS),
         documentation('trec-web-2013'))
+    
+    subsets['trec-web-2013/diversity'] = Dataset(
+        collection,
+        TrecXmlQueries(dlc['trec-web-2013/queries'], qtype=TrecWebTrackQuery, namespace='trec-web', lang='en'),
+        TrecSubQrels(dlc['trec-web-2013/qrels.all'], QREL_DEFS),
+        documentation('trec-web-2013/diversity'))
 
     subsets['trec-web-2014'] = Dataset(
         collection,
@@ -280,6 +286,12 @@ def _init():
         TrecQrels(dlc['trec-web-2014/qrels.adhoc'], QREL_DEFS),
         documentation('trec-web-2014'))
 
+    subsets['trec-web-2014/diversity'] = Dataset(
+        collection,
+        TrecXmlQueries(dlc['trec-web-2014/queries'], qtype=TrecWebTrackQuery, namespace='trec-web', lang='en'),
+        TrecSubQrels(dlc['trec-web-2014/qrels.all'], QREL_DEFS),
+        documentation('trec-web-2014/diversity'))
+
     subsets['b13/ntcir-www-1'] = Dataset(
         collection_b13,
         TrecXmlQueries(Cache(ZipExtract(dlc['ntcir-www-1/queries'], 'eng.queries.xml'), base_path/'ntcir-www-1'/'queries.xml'), qtype=GenericQuery, qtype_map={'qid': 'query_id', 'content': 'text'}, namespace='ntcir-www', lang='en'),
