@@ -2,7 +2,7 @@ from .base import GenericDoc, GenericQuery, GenericQrel, GenericScoredDoc, Gener
 from .base import BaseDocs, BaseQueries, BaseQrels, BaseScoredDocs, BaseDocPairs
 from .csv_fmt import CsvDocs, CsvQueries, CsvDocPairs
 from .tsv import TsvDocs, TsvQueries, TsvDocPairs
-from .trec import TrecDocs, TrecQueries, TrecXmlQueries, TrecColonQueries, TrecQrels, TrecPrels, TrecScoredDocs, TrecDoc, TitleUrlTextDoc, TrecQuery, TrecSubtopic, TrecQrel, TrecPrel, TrecParsedDoc
+from .trec import TrecDocs, TrecQueries, TrecXmlQueries, TrecColonQueries, TrecQrels, TrecSubQrels, TrecPrels, TrecScoredDocs, TrecDoc, TitleUrlTextDoc, TrecQuery, TrecSubtopic, TrecQrel, TrecSubQrel, TrecPrel, TrecParsedDoc
 from .touche import (
     ToucheQueries, ToucheQuery, ToucheTitleQuery, ToucheQrels
 )
@@ -15,4 +15,4 @@ from .argsme import (
 )
 
 from .extracted_cc import ExctractedCCDoc, ExctractedCCDocs, ExctractedCCQuery, ExctractedCCQueries
-from .jsonl import JsonlDocs
+from .jsonl import JsonlDocs, JsonlQueries
